# Table of Contents

- [application-rationalization-start-initiative](<./application-rationalization-start-initiative.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Step 6: Start the Rationalization Initiative](<./Step-6-Start-the-Rationalization-Initiative.md>)
  - [Create Transformations](<./Step-6-Start-the-Rationalization-Initiative/Create-Transformations.md>)
  - [Start Transformations](<./Step-6-Start-the-Rationalization-Initiative/Start-Transformations.md>)
